@@ -11,6 +11,7 @@ class Articles:
     _url_get_article_lot_ex = '/articles_lots/ex?lot={lot}&article_atribut_id={article_atribut_id}'
     _url_get_article_lot_id = '/articles_lots/{id}'
     _url_get_article_estoc_magatzem = '/articles_estocs/{article_atribut_id}?magatzem_id={magatzem_id}'
+    _url_get_article_lot_estoc_magatzem = '/articles_estocs/{article_atribut_id}/lots?magatzem_id={magatzem_id}'
     _url_post_article_lot = '/articles_lots'
 
     def __init__(self, con: JManCon):
@@ -100,6 +101,16 @@ class Articles:
             llista = req.json()
         return llista
 
+    def get_article_lot_estoc_magatzem(self, p_article_atribut: int, p_magatzem: int):
+        tmp_url = Articles._url_get_article_lot_estoc_magatzem.format(
+            article_atribut_id=p_article_atribut, magatzem_id=p_magatzem
+        )
+        req = self._con.get(url=tmp_url)
+        llista = None
+        if req is not None:
+            llista = req.json()
+        return llista
+
     def post_article_lot(self, p_data: dict):
         req = self._con.post(url=Articles._url_post_article_lot, data=p_data)
         return req.json()
