@@ -12,6 +12,7 @@ class Comandes:
     _url_tancar = '/comandes/{id_com}/tancar'
     _url_albarans = '/comandes/{id_com}/albarans/iniciats'
     _url_comanda_distribucio = '/comandes/{id_com}/distribucio'
+    _url_comanda_imprimir = '/comandes/{id_com}/imprimir'
 
     def __init__(self, con: JManCon):
         self._con = con
@@ -57,3 +58,7 @@ class Comandes:
         tmp_url = Comandes._url_comanda_distribucio.format(id_com=comanda_distribucio["comanda_id"])
         req = self._con.put(url=tmp_url, data=comanda_distribucio)
         return req.json()
+
+    def get_comanda_imprimir(self, p_comanda_id: int):
+        req = self._con.get(url=self._url_comanda_imprimir.format(id_com=p_comanda_id))
+        return req.json()
