@@ -31,6 +31,12 @@ from proveidors p
 join tercers t on p.TERCER_ID = t.ID
 """
 
+sync_empleats = """
+select e.EMPRESA_ID, t.ID, e.ID, t.NOM_LLARG, e.DATA_BAIXA
+from empleats e 
+join tercers t on e.TERCER_ID = t.ID
+"""
+
 sync_condicions_pagament = """
   select c.ID, c.condicio_pagament
     from condicions_pagament c
@@ -49,6 +55,7 @@ select
     c.NUMERO_COMANDA,
     c.REFERENCIA,
     cd.TERCER_ID CLIENT_ID,
+    c.EMPLEAT_ID,
     cd.REPARTIDOR_ID,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_ter.NOM_LLARG_I_COMERCIAL ELSE c_cli.TERCER END NOM_CLIENT,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_carrer.CARRER ELSE c_cli.ADRECA END ADRECA,
